<html>

<header>
<link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.6/css/bootstrap.min.css" integrity="sha384-1q8mTJOASx8j1Au+a5WDVnPi2lkFfwwEAa8hDDdjZlpLegxhjVME1fgjWPGmkzs7" crossorigin="anonymous">
</header>

<body>

<div class="container">
<div class="row">
 <div class="col-md-6 col-md-offset-3">
    <table class="table">


    {{form}}

    </table>
</div>
</div>
</div>

{{form.media}}

</body>

</html>
